@@ -18,11 +18,11 @@ Locale::Maketext::Test
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -31,7 +31,8 @@ our $VERSION = '0.03';
     my $foo = Locale::Maketext::Test->new(directory => '/tmp/locales'); # it will look for files like id.po, ru.po
 
     ### optional parameters
-    # languages => ['en', 'de'] - to test specific languages in directory, else it will pick all po files in directory ideally these languages should be as per https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes format
+    # languages => ['en', 'de'] - to test specific languages in directory, else it will pick all po files in directory
+    # ideally these languages should be as per https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes format
     # debug     => 1 - if you want to check warnings add debug flag else it will output errors only
     # auto      => 1 set only when you want to fallback in case a key is missing from lexicons
 
@@ -184,8 +185,8 @@ sub BUILD {
         my @lang = ();
         if (opendir my $dh, $self->directory) {
             while (readdir $dh) {
-                if (my ($x) = grep { $_ =~ /^(\w+)\.po$/ } $_) {
-                    push @lang, ($x) = split(/\./, $x);
+                if (my ($x) = ($_ =~ /^(\w+)\.po$/)) {
+                    push @lang, $x;
                 }
             }
             @lang = sort @lang;
